@@ -24,7 +24,6 @@
 #' @param ... ignored
 #' @importFrom units as_units as_units
 #' @importFrom graphics par plot abline
-#' @importFrom fields image.plot
 #' @importFrom grDevices rgb colorRamp
 #'
 #' @rdname Emissions
@@ -189,13 +188,23 @@ plot.Emissions <- function(x,
                                                bias = bias)(seq(0, 1,0.01)),
                           maxColorValue = 255)
 
-    fields::image.plot(
-      x = 1:ncol(x),
-      xaxt = "n",
-      z =t(as.matrix(x))[, nrow(x):1],
-      xlab = "",
-      ylab = paste0("Emissions by streets [",as.character(units(x[[1]])), "]"),
-      col = col, horizontal = TRUE)
+    # fields::image.plot(
+    #   x = 1:ncol(x),
+    #   xaxt = "n",
+    #   z =t(as.matrix(x))[, nrow(x):1],
+    #   xlab = "",
+    #   ylab = paste0("Emissions by streets [",as.character(units(x[[1]])), "]"),
+    #   col = col, horizontal = TRUE)
+
+    graphics::image(x = 1:ncol(x),
+                    xaxt = "n",
+                    z =t(as.matrix(x))[, nrow(x):1],
+                    xlab = "",
+                    ylab = paste0("Emissions by streets [",as.character(units(x[[1]])), "]"),
+                    col = col,
+                    axe = FALSE)
+    axis(2)
+    addscale(t(as.matrix(x))[, nrow(x):1], col = col)
 
     graphics::par(fig=fig2,
                   mai = mai2,
@@ -218,7 +227,7 @@ plot.Emissions <- function(x,
                   ...)
     graphics::plot(x = rowSums(x, na.rm = T), y = nrow(x):1,
                    type = "l", frame = FALSE, yaxt = "n",
-                   ylab = NULL, xlab = NULL
+                   ylab = "", xlab = NULL
     )
     graphics::abline(v = avage, col="red")
 
