@@ -8,13 +8,13 @@
 #' @param x0 Numeric;  the x-value of the sigmoid's midpoint,
 #' @param k Numeric; the steepness of the curve.
 #' @param L Integer; the curve's maximum value.
-#' @return dataframe of age distrubution of vehicles at each street.
+#' @param verbose Logical; to show the equation.
+#' @return numeric vector.
 #' @export
 #' @references https://en.wikipedia.org/wiki/Logistic_function
 #' @examples \dontrun{
-#' data(fe2015)
 #' CO <- ef_cetesb(p = "CO", veh = "PC_G")
-#' ef_logit <- ef_fun(ef = CO, x0 = 27, k = 0.4, L = 33)
+#' ef_logit <- ef_fun(ef = CO, x0 = 27, k = 0.4, L = max(CO))
 #' df <- data.frame(CO, ef_logit)
 #' colplot(df)
 #' }
@@ -23,11 +23,13 @@ ef_fun <- function(ef,
                    x = 1:length(ef),
                    x0 = mean(ef),
                    k = 1/4,
-                   L = max(ef)) {
+                   L = max(ef),
+                   verbose = TRUE) {
   if(type == "logistic"){
     FD <- function(x, x0, L, k) {
       L/(1 + exp(1)^(-k*(x - x0))  )
     }
+    if(verbose) print(FD)
     a <- vein::EmissionFactors(FD(x, x0 = x0, k = k, L = L))
     return(a)
   }
